@@ -22,7 +22,7 @@ def get_template_path(template_name):
     return os.path.join(templates_path, template_name)
     
 
-def activate_venv():
+def activate_venv(path):
 
     parent = os.getcwd()
     os.system("python -m venv env")
@@ -31,14 +31,18 @@ def activate_venv():
     if OS == "Windows":
         env_activate_script = "Scripts"
 
-
-    activate_file = os.path.join(parent, "env", env_activate_script, "activate")
+    print("---path ", path)
+    activate_file = os.path.join(path, "env", env_activate_script, "activate")
+    print("---activate_file ", activate_file)
     os.system(f"{activate_file} && pip install -r requirements.txt")
 
 
-@app.command()
+@app.command("")
 def main(template_name):
     template_path = get_template_path(template_name)
-    cookiecutter(template_path)
-    activate_venv()
+    res = cookiecutter(template_path)
+    project_path = os.path.join(template_path, template_name)
+    print("---project_path", project_path)
+    print("--res", res)
+    activate_venv(project_path)
 
